/**
 * Author: Valerio Schiavoni <valerio.schiavoni@gmail.com>
 */
package org.objectweb.fractal.bf.adl.common;

import java.util.Map;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.AbstractLoader;
import org.objectweb.fractal.adl.Definition;
import org.objectweb.fractal.adl.components.Component;
import org.objectweb.fractal.adl.components.ComponentContainer;

/**
 * 
 */
public abstract class BindingFactoryLoader extends AbstractLoader
{

  /**
   * @see org.objectweb.fractal.adl.Loader#load(java.lang.String, java.util.Map)
   */
  public Definition load(String name, Map<Object, Object> context)
      throws ADLException
  {
    Definition d = clientLoader.load(name, context);
    checkNode(d);
    return d;
  }

  /**
   * @param node
   * @throws ADLException if the node doesn't provide values for the type and
   *             the interface attributes
   */
  private void checkNode(Object node) throws ADLException
  {
    performSpecificChecksOn(node);
    if (node instanceof ComponentContainer)
    {
      ComponentContainer componentContainer = (ComponentContainer) node;

      Component[] comps = componentContainer.getComponents();
      if (comps != null)
      {
        for (int i = 0; i < comps.length; i++)
        {
          checkNode(comps[i]);

        }
      }
    }
  }

  /**
   * @param node
   */
  protected abstract void performSpecificChecksOn(Object node)  throws ADLException;
 
}
